﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            Tektronix TBS1072B: (1 year) VER VISA /5800A+1Ch
DATE:                  2018-08-09 15:47:44
AUTHOR:                Fluke
REVISION:              $Revision: 25085 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       210
CONFIGURATION:         Fluke 5800A
=============================================================================
#
#  Procedure Author:
#      PP
#
#  Source(s):
#      TBS1000B and TBS1000B-EDU Series Oscilloscopes
#      Specifications and Performance Verification
#      Technical Reference, PN 077-1025-01, Revision B.*
#      * The tolerances used by this procedure were taken from the published
#      specifications table and is specified below.
#
#  Model(s) Covered:
#      TBS1000B Series
#          TBS1032B, TBS1052B, TBS1072B, TBS1102B, TBS1152B
#		   TBS1202B.
#      TBS1000B-EDU Series
#          TBS1052B-EDU, TBS1072B-EDU, TBS1102B-EDU,
#		   TBS1152B-EDU, TBS1202B-EDU
#
#  Compatibility:
#      MET/CAL 8.0 or later
#
#  Additional Equipment Required:
#      None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# These statements are here to force the main procedure header to list the
# configuration required by the subprocedures.
  1.001  IF           0
  1.002  5800         60MH                         1Vpp           LS S6 S  L
  1.003  ENDIF

  1.004  ASK-   R   Q N              P                                    V

  1.006  IF           NOT(VERSIONCHECK("8.0"))
  1.007  END
  1.008  ENDIF

  1.009  CALL         Sub Display Copyright
  1.010  CALL         Sub High Voltage Safety Warning
  1.011  CALL         Sub Select Failed Test Mode
  1.012  CALL         Sub Select Verification Method (No NTHROW)

  1.012  HEAD         PRELIMINARY INSTRUCTIONS
  1.013  DISP         Ensure a minimum DUT warm-up time of at least
  1.013  DISP         10 minutes has been allowed to elapse, prior
  1.013  DISP         to beginning verification.

  1.014  HEAD         COMMUNICATION SETUP
  1.015  TARGET
  1.016  CALL         Sub Tek TBS1000B USB Remote Interface Connection
  1.017  VISA         *RST

  1.018  HEAD         DUT IDENTIFICATION
  1.019  CALL         Sub IEEE-488.2 *IDN? VISA
  1.020  MATH         @DUT_Model = "TBS 1072B"
  1.021  MATH         @DUT_Manufacturer = "Tektronix"
  1.022  CALL         Sub IEEE-488.2 *IDN? Check Response
  1.023  JMPL         END                          @Abort

  1.024  CALL         Sub Tek TBS1000B/1000B-EDU Specifications

# Specify whether the calibrator have multi channels during test in order
# to decide proper connection instruction be taken in the sub procedures.
  1.025  MATH         @SourceMultiCh = 0

  1.026  HEAD         EQUIPMENT REQUIREMENTS
  1.027  OPBR         -z Do you want to REVIEW the list of additional
  1.027  OPBR         equipment and/or accessories required?

  1.028  IF           MEM1
  1.029  CALL         Sub Tek TBS1000B/1000B-EDU VER Required Equipment /5800
  1.030  ENDIF

# NOTE: The execution order of this verification procedure has been optimized
# to minimize operator intervention, while retaining the correct sequence for
# reported test results.  For more information about the method used, refer
# to this application note, available at www.flukecal.com:
# Application Note 6001075: Optimizing Execution Sequence in MET/CAL Gold
# Procedures While Retaining Results Order.

  1.031  CALL         Sub Tek TBS1000B/1000B-EDU Self-Test VISA
  1.032  JMPL         END                          @Abort
  1.033  CALL         Sub Tek TBS1000B/1000B-EDU Sig Path Comp Cal VISA
  1.034  JMPL         END                          @Abort

  1.035  MATH         @Chan = 1
  1.036  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) DCV Meas VISA /5800
  1.037  JMPL         VERTICAL_POSITION_CH1

  1.038  LABEL        DCV_CH2
  1.039  MATH         @Chan = 2
  1.040  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) DCV Meas VISA /5800
  1.041  JMPL         VERTICAL_POSITION_CH2

  1.042  LABEL        BANDWIDTH_CH1
  1.043  MATH         @Chan = 1
  1.044  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Bandwidth VISA /5800
  1.045  JMPL         TRIG_CH1

  1.046  LABEL        BANDWIDTH_CH2
  1.047  MATH         @Chan = 2
  1.048  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Bandwidth VISA /5800
  1.049  JMPL         TRIG_CH2

  1.050  LABEL        TRIG_CH1
  1.051  MATH         @Chan = 1
  1.052  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Trig Sens VISA /5800
  1.053  JMPL         SAMPLE_RATE_DELAY_TIME

  1.054  LABEL        TRIG_CH2
  1.055  MATH         @Chan = 2
  1.056  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Trig Sens VISA /5800

  1.057  MATH         @Chan = 1
  1.058  CALL         Sub Tek TBS1000B (1 yr) ExTrig Sens VISA /5800

  1.059  MATH         @Chan = 2
  1.060  CALL         Sub Tek TBS1000B (1 yr) ExTrig Sens VISA /5800
  1.061  JMPL         END

  1.062  LABEL        SAMPLE_RATE_DELAY_TIME
  1.063  MATH         @Chan = 1
  1.064  CALL         Sub Tek TBS1000B (1 yr) Sample Rate VISA /5800
  1.065  JMPL         BANDWIDTH_CH2

  1.066  LABEL        VERTICAL_POSITION_CH1
  1.067  MATH         @Chan = 1
  1.068  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Vert Pos VISA /5800
  1.069  JMPL         DCV_CH2

  1.070  LABEL        VERTICAL_POSITION_CH2
  1.071  MATH         @Chan = 2
  1.072  CALL         Sub Tek TBS1000B/1000B-EDU (1 yr) Vert Pos VISA /5800
  1.073  JMPL         BANDWIDTH_CH1

  1.074  LABEL        END

  1.075  IF           @Abort
  1.076  HEAD         {V E R I F I C A T I O N   A B O R T E D !}
  1.077  ENDIF

  1.078  VISA         *RST
  1.079  END
